@@ -31,8 +31,8 @@ class ServerSettingsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit ServerSettingsWidget(ParameterEditModel *model,
-                                       QWidget *parent = 0);
-    virtual ~ServerSettingsWidget();
+                                       QWidget *parent = nullptr);
+    ~ServerSettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(ServerSettingsWidget)
