@@ -30,10 +30,10 @@ class IcqMainOptionsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 public:
     explicit IcqMainOptionsWidget(ParameterEditModel *model,
-                                  QWidget *parent = 0);
-    virtual ~IcqMainOptionsWidget();
+                                  QWidget *parent = nullptr);
+    ~IcqMainOptionsWidget() override;
 
-    virtual QString defaultDisplayName() const override;
+    QString defaultDisplayName() const override;
 private:
     Q_DISABLE_COPY(IcqMainOptionsWidget)
     Ui::IcqMainOptionsWidget *m_ui;
