@@ -31,8 +31,8 @@ class AdvancedOptionsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit AdvancedOptionsWidget(ParameterEditModel *model,
-                               QWidget *parent = 0);
-    virtual ~AdvancedOptionsWidget();
+                               QWidget *parent = nullptr);
+    ~AdvancedOptionsWidget() override;
 
 private:
     Q_DISABLE_COPY(AdvancedOptionsWidget)
