@@ -28,16 +28,16 @@ class SunshineAccountUi : public AbstractAccountUi
     Q_OBJECT
 
 public:
-    explicit SunshineAccountUi(QObject *parent = 0);
-    virtual ~SunshineAccountUi();
+    explicit SunshineAccountUi(QObject *parent = nullptr);
+    ~SunshineAccountUi() override;
 
-    virtual AbstractAccountParametersWidget
+    AbstractAccountParametersWidget
     *mainOptionsWidget(ParameterEditModel *model,
-                       QWidget *parent = 0) const override;
-    virtual bool hasAdvancedOptionsWidget() const override;
-    virtual AbstractAccountParametersWidget
+                       QWidget *parent = nullptr) const override;
+    bool hasAdvancedOptionsWidget() const override;
+    AbstractAccountParametersWidget
     *advancedOptionsWidget(ParameterEditModel *model,
-                           QWidget *parent = 0) const override;
+                           QWidget *parent = nullptr) const override;
 
 private:
     Q_DISABLE_COPY(SunshineAccountUi)
