@@ -31,8 +31,8 @@ class SunshineAdvancedOptionsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit SunshineAdvancedOptionsWidget(ParameterEditModel *model,
-                                        QWidget *parent = 0);
-    virtual ~SunshineAdvancedOptionsWidget();
+                                        QWidget *parent = nullptr);
+    ~SunshineAdvancedOptionsWidget() override;
 
 private:
     Q_DISABLE_COPY(SunshineAdvancedOptionsWidget)
