@@ -46,8 +46,8 @@ public:
                                const QString &displayName,
                                ParameterEditModel *parameterModel,
                                ConnectOnLoadType connectOnAddFlag = doNotConnectOnAdd,
-                               QWidget *parent = 0);
-    virtual ~AccountEditWidget();
+                               QWidget *parent = nullptr);
+    ~AccountEditWidget() override;
 
     QString errorMessage() const;
     virtual bool validateParameterValues() const;
